#!/bin/bash
file_num=2 #备份文件超过3个删除
redis_port=26312
redis_backup_time=`date +%Y%m%d%H%M%S`  #定义备份详细时间
redis_backup_table="dump.rdb"  #备份数据文件名称
redis_backup_db="/home/seekcy/softs/" #备份数据存放位置

source /home/seekcy/.bash_profile

dir=$(cd "$(dirname "$0")"; pwd)

log_file_dir=$dir/logs/$(date +"%Y-%m-%d")".log"
redis_backup_dir="$dir/data/redis/"  #备份数据存放位置

function log_print()
{
    time=$(date +"%Y-%m-%d %H:%M:%S")
    write_str="$time $* "
    echo $write_str >> $log_file_dir
}
log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
log_print "Welcome to use redis backup tools!"
log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"

if [ -z "$redis_backup_dir" ];then
	log_print "ERROR:Please fill redis_backup_dir in open_redis_backup.sh"
	exit
fi

if [ -z "$redis_backup_table" ];then
	log_print "ERROR:Please fill redis_backup_table in open_redis_backup.sh"
	exit
fi

if [ -z "$redis_backup_db" ];then
	log_print "ERROR:Please fill redis_backup_db in open_redis_backup.sh"
fi


# 判断redis是否启动,redis没有启动则备份退出
redis_ps=`ps -ef |grep redis-server |wc -l`
redis_listen=`netstat -an |grep LISTEN |grep $redis_port|wc -l`
if [[ $redis_ps -le 1 ||  $redis_listen == 0 ]]; then
    log_print "ERROR:redis is not running! backup stop!"
    exit
else
    log_print "Redis backup start >>"
fi

#判断文件夹是否存在
if [[ ! -d "$redis_backup_dir" ]]; then
	`mkdir -p $redis_backup_dir`
	log_print "create $redis_backup_dir success"
else
	#删除已备份数据
	num_all=`ls -l $redis_backup_dir | grep $redis_backup_table |grep "^-"|wc -l`
	if [[ $num_all -ge $file_num ]];then
		num=$[num_all-file_num]
		for i in `ls -trF $redis_backup_dir | grep $redis_backup_table | head -n $num`	
		do
			`rm -rf $redis_backup_dir$i`
			log_print "delete $redis_backup_dir$i complete!"
		done
		log_print "Expired $num num backup files delete complete!"
	fi
fi

cp $redis_backup_db$redis_backup_table  $redis_backup_dir$redis_backup_time-$redis_backup_table

flag=`echo $?`
if [ $flag == "0" ];then
	log_print "database $redis_backup_db backup to $redis_backup_dir$redis_backup_time-$redis_backup_table success!"
	log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
	log_print "Redis backup success !"
	log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
else
	log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
	log_print "database $redis_backup_db backup fail!"
	log_print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
fi